@@ -9,7 +9,7 @@ for d3.js without taking away the power that d3.js gives you.
 Project location : https://github.com/areski/python-nvd3
 """
 
-__version__ = '0.9.0'
+__version__ = '0.10.0'
 
 
 from .lineChart import lineChart
@@ -22,6 +22,7 @@ from .cumulativeLineChart import cumulativeLineChart
 from .scatterChart import scatterChart
 from .discreteBarChart import discreteBarChart
 from .multiBarChart import multiBarChart
+from .linePlusBarWithFocusChart import linePlusBarWithFocusChart
 
 
 class lineChart(lineChart):
@@ -36,6 +37,10 @@ class lineWithFocusChart(lineWithFocusChart):
     pass
 
 
+class linePlusBarWithFocusChart(linePlusBarWithFocusChart):
+    pass
+
+
 class stackedAreaChart(stackedAreaChart):
     pass
 
